==> haskell-type-errors-0.2.0.2-77-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-type-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 type-errors
version:              0.2.0.2
visibility:           public
id:                   type-errors-0.2.0.2-KT235T8A4l0KgE449R4fyf
key:                  type-errors-0.2.0.2-KT235T8A4l0KgE449R4fyf
license:              BSD-3-Clause
copyright:            2019 Sandy Maguire
maintainer:           sandy@sandymaguire.me
author:               Sandy Maguire
homepage:             https://github.com/isovector/type-errors#readme
synopsis:             Tools for writing better type errors
description:
    Please see the README on GitHub at <https://github.com/isovector/type-errors#readme>

category:             Type
abi:                  c05283057d4a129b7d487c594de97e07
exposed:              True
exposed-modules:      Type.Errors
hidden-modules:       Paths_type_errors
import-dirs:          /usr/lib/ghc-9.4.8/site-local/type-errors-0.2.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/type-errors-0.2.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/type-errors-0.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-type-errors
hs-libraries:         HStype-errors-0.2.0.2-KT235T8A4l0KgE449R4fyf
depends:
    base-4.17.2.1 first-class-families-0.8.1.0-GHDQ6gIu3MO757TPVLJ5eT
    syb-0.7.2.4-LBhYOmNvCTD9nmTNYbjxYb template-haskell-2.19.0.0
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy

haddock-interfaces:   /usr/share/doc/haskell-type-errors/html/type-errors.haddock
haddock-html:         /usr/share/doc/haskell-type-errors/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-type-errors-0.2.0.2-78-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-type-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 type-errors
version:              0.2.0.2
visibility:           public
id:                   type-errors-0.2.0.2-l25LOZdTQp90BDZ6r9F0W
key:                  type-errors-0.2.0.2-l25LOZdTQp90BDZ6r9F0W
license:              BSD-3-Clause
copyright:            2019 Sandy Maguire
maintainer:           sandy@sandymaguire.me
author:               Sandy Maguire
homepage:             https://github.com/isovector/type-errors#readme
synopsis:             Tools for writing better type errors
description:
    Please see the README on GitHub at <https://github.com/isovector/type-errors#readme>

category:             Type
abi:                  2b702cac4850943be5f1c064c50cd651
exposed:              True
exposed-modules:      Type.Errors
hidden-modules:       Paths_type_errors
import-dirs:          /usr/lib/ghc-9.4.8/site-local/type-errors-0.2.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/type-errors-0.2.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/type-errors-0.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-type-errors
hs-libraries:         HStype-errors-0.2.0.2-l25LOZdTQp90BDZ6r9F0W
depends:
    base-4.17.2.1 first-class-families-0.8.1.0-GHDQ6gIu3MO757TPVLJ5eT
    syb-0.7.2.4-3MUyG3p3euQLeyQ65NE0AP template-haskell-2.19.0.0
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy

haddock-interfaces:   /usr/share/doc/haskell-type-errors/html/type-errors.haddock
haddock-html:         /usr/share/doc/haskell-type-errors/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
